==> rivendell-1.7.0.tar.gz: rivendell-1.7.0/rdhpi/rdhpi_nb.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>RDHPIPlayStream</name>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>No such file or directory</source>
        <translation>Inga slik fil eller mappe</translation>
    </message>
    <message>
        <source>No output stream available</source>
        <translation>Ingen tilgjengeleg utstraum</translation>
    </message>
    <message>
        <source>Stream is already open</source>
        <translation>Straumen er alt open</translation>
    </message>
    <message>
        <source>Unknown Error:</source>
        <translation>Ukjend feil:</translation>
    </message>
</context>
<context>
    <name>RDHPIRecordStream</name>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Unable to create/open file</source>
        <translation>Greier ikkje opna/laga fila</translation>
    </message>
    <message>
        <source>Input stream unavailable</source>
        <translation>Innstraumen er ikkje tilgjengeleg</translation>
    </message>
    <message>
        <source>Stream is already open</source>
        <translation>Straumen er alt open</translation>
    </message>
    <message>
        <source>Unknown Error:</source>
        <translation>Ukjend feil:</translation>
    </message>
</context>
<context>
    <name>RDHPISoundCard</name>
    <message>
        <source>Input Stream</source>
        <translation>Innstraum</translation>
    </message>
    <message>
        <source>Output Stream</source>
        <translation>Utstraum</translation>
    </message>
    <message>
        <source>Input Port</source>
        <translation>Innport</translation>
    </message>
    <message>
        <source>Output Port</source>
        <translation>Utport</translation>
    </message>
</context>
</TS>

==> rivendell-3.6.1.tar.gz: rivendell-3.6.1/rdhpi/rdhpi_nb.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>RDHPIPlayStream</name>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>No such file or directory</source>
        <translation>Inga slik fil eller mappe</translation>
    </message>
    <message>
        <source>No output stream available</source>
        <translation>Ingen tilgjengeleg utstraum</translation>
    </message>
    <message>
        <source>Stream is already open</source>
        <translation>Straumen er alt open</translation>
    </message>
    <message>
        <source>Unknown Error:</source>
        <translation type="obsolete">Ukjend feil:</translation>
    </message>
    <message>
        <source>Unknown RDHpiPlayStream Error:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDHPIRecordStream</name>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Unable to create/open file</source>
        <translation>Greier ikkje opna/laga fila</translation>
    </message>
    <message>
        <source>Input stream unavailable</source>
        <translation>Innstraumen er ikkje tilgjengeleg</translation>
    </message>
    <message>
        <source>Stream is already open</source>
        <translation>Straumen er alt open</translation>
    </message>
    <message>
        <source>Unknown Error:</source>
        <translation type="obsolete">Ukjend feil:</translation>
    </message>
    <message>
        <source>Unknown RDHpiRecordStream Error:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDHPISoundCard</name>
    <message>
        <source>Input Stream</source>
        <translation>Innstraum</translation>
    </message>
    <message>
        <source>Output Stream</source>
        <translation>Utstraum</translation>
    </message>
    <message>
        <source>Input Port</source>
        <translation>Innport</translation>
    </message>
    <message>
        <source>Output Port</source>
        <translation>Utport</translation>
    </message>
</context>
</TS>
